def main(argv=None):
    cmd = PysqesCommand()
    cmd.execute()

if __name__ == '__main__':          # pragma: no cover
    print("entry point")
